@@ -2,5 +2,5 @@
 # Use of this source code is governed by a BSD-style
 # license that can be found in the LICENSE file.
 
-from .listener import Listener
+from .client import AsyncMothrClient
 from .request import AsyncJobRequest
